@@ -1,6 +1,9 @@
 #!/usr/bin/env python
 
-from __future__ import unicode_literals
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
 from pyopsview.utils import version_cmp
 
 
